/*************************************************************************
Testprogramm fr die Originalplatine mit 8 LED-Matrixanzeigen DLG7137,
die per I2C ber 2 Portexpander PCF8574 angesteuert werden.

Hardware: ATtiny85 mit internem 8MHz Takt, Fuses Low=E2, High=DF
Die I2C Ansteuerung erfolgt per Bitbang mit der "Fleury" Bibliothek
Dort in "i2cmaster.s" sind auch die Port-Zuordnungen definiert.
SDA=PB0, Pin 5
SCL=PB1, Pin 6	Die 4k7 Pull-up Widerstnde sind auf der Displayplatine.

Die I2C Adressen sind 0x48 fr die Steuersignale und 0x4A fr die Daten.
Hierzu muss A1, Pin6 auf Gnd und A2 Pin 7 auf +5V gelegt werden.

TN 08/04/2025
*************************************************************************/

#include <avr/io.h>					// Header Dateien
#include <util/delay.h>
#include "i2cmaster.h"
/*
     fixed   | A2 A1 A0 Write
  0  1  0  0 | 1  0  0  0			   Command PCF8574 = 0x48
  0  1  0  0 | 1  0  1  0			   Data PCF8574 = 0x4A
*/
#define	CtrlReg	0x48
#define DataReg	0x4A

const uint8_t displayIndex[] = {151, 150, 149, 148, 143, 142, 141, 140};
static char TextMsg[8] = "Osterei!";

void Display_writedata(uint8_t data)// Schreibt parallele Daten zum Display
{
	i2c_start(DataReg);
	i2c_write(data);
	i2c_stop();						// I2C Bus wieder freigeben
}

void PutChar(uint8_t Zeichen, uint8_t pos)
{
	Display_writedata(Zeichen);		// Daten an Bus legen
    i2c_start(CtrlReg);
	i2c_write(displayIndex[pos]);	// Display per /CS whlen
	i2c_write(196);					// Write Impuls erzeugen
	i2c_stop();						// Bus freigeben
}

////////
//Main//
////////
int main(void)
{
	i2c_init();						// SDA/SCL Portpins I/O initialisieren

	for (uint8_t i=0; i<8; i++) PutChar(TextMsg[i], i);

	Display_writedata(7);			// 100% Helligkeit
	i2c_start(CtrlReg);				// bertragung abschlieen
	i2c_write (128);				// Clear FlipFlop
	i2c_write (159);				// clk Signal fr Flipflop
	i2c_stop();

	while(1)
	{
		i2c_start(CtrlReg);
		i2c_write(0b11010000);		// BAR_FF_STATE1 (Bit6) setzen (D-Eingang U8B fr grne LED)
		i2c_write(0b11010001);		// BAR_FF_CLK (Bit0) setzen (positive Taktflanke an D-Flipflop)
		i2c_stop();
		Display_writedata(6);		// 50% Helligkeit: Betrifft Ziffern & LED-Balken

		_delay_ms (500);

		i2c_start(CtrlReg);			// HIER SOLLEN DIE LED EIGENTLICH WIEDER AUSSCAHLTEN
		i2c_write(0b10010000);		// BAR_FF_STATE1 und BAR_FF_CLK lschen,
		i2c_write(0b10010001);		// eintakten => LED ausschalten
		i2c_stop();
		Display_writedata(7);		// 100% Helligkeit

		_delay_ms (500);
	}
}
